# $Id: notice-policy.bro,v 1.5 2006/04/19 22:34:14 vern Exp $

# Examples of using notice_policy and other mechanisms to filter out
# alarms that are not interesting.

# Note: this file is not self-contained, in that it refers to Notice
# names that will only be defined if you've loaded other files (e.g.,
# print-resources for the ResourceSummary notice).  The full list of
# policy files it needs is:
#
#	blaster.bro
#	conn.bro
#	http-request.bro
#	netstats.bro
#	print-resources.bro
#	trw.bro
#	weird.bro


# Remove these notices from logging since they can be too noisy.
redef notice_action_filters += {
        [[ContentGap, AckAboveHole]] = ignore_notice,
};

# Send these only to the notice log, not the alarm log.
redef notice_action_filters += {
        [[AddressDropIgnored, DroppedPackets,
	  ResourceSummary, W32B_SourceRemote,
	  WeirdActivity, TRW::TRWScanSummary,
	  BackscatterSeen, RetransmissionInconsistency]] = file_notice,
};

# Fine-grained filtering of specific alarms.
redef notice_policy += {

	# Connections to 2766/tcp ("Solaris listen service") appear
	# nearly always actually due to P2P apps.
        [$pred(n: notice_info) =
		{
		return n$note == SensitiveConnection &&
 		       /Solaris listen service/ in n$msg;
		},
         $result = NOTICE_FILE,
         $priority = 1],

	# Ignore sensitive URLs that end in .gif, .jpg, .png
	[$pred(n: notice_info) =
		{
		return n$note == HTTP::HTTP_SensitiveURI &&
		       n$URL == /.*\.(gif|GIF|png|PNG|jpg|JPG)/; 
		},
	 $result = NOTICE_FILE,
	 $priority = 1],
};
